This is the public implementation of the low-level modules supporting PEP 734.

The modules provided by the package should mostly not be used directly.
For the high-level modules, see https://pypi.org/project/interpreters-pep-734/.

On Python 3.13+, the low-level modules already ship with Python.

Nearly all development for this project is done in the upstream CPython repo.
